@@ -296,13 +296,13 @@ class KinesisStreamsToKinesisFirehoseToS3Props:
         :param log_s3_access_logs: Whether to turn on Access Logs for the S3 bucket with the associated storage costs. Enabling Access Logging is a best practice. Default: - true
         '''
         if isinstance(bucket_props, dict):
-            bucket_props = BucketProps(**bucket_props)
+            bucket_props = aws_cdk.aws_s3.BucketProps(**bucket_props)
         if isinstance(kinesis_stream_props, dict):
-            kinesis_stream_props = StreamProps(**kinesis_stream_props)
+            kinesis_stream_props = aws_cdk.aws_kinesis.StreamProps(**kinesis_stream_props)
         if isinstance(logging_bucket_props, dict):
-            logging_bucket_props = BucketProps(**logging_bucket_props)
+            logging_bucket_props = aws_cdk.aws_s3.BucketProps(**logging_bucket_props)
         if isinstance(log_group_props, dict):
-            log_group_props = LogGroupProps(**log_group_props)
+            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if __debug__:
             type_hints = typing.get_type_hints(KinesisStreamsToKinesisFirehoseToS3Props.__init__)
             check_type(argname="argument bucket_props", value=bucket_props, expected_type=type_hints["bucket_props"])
